==> jc-1.4.0.tar.gz: java/util/logging/ErrorManager.h <==
// public class java.util.logging.ErrorManager

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bb2b34e6afd34e3a java_util_logging_ErrorManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_logging_ErrorManager_H_
#define _JC_java_util_logging_ErrorManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_util_logging_ErrorManager$sub_refs	_jc_java_util_logging_ErrorManager$sub_refs;
typedef struct _jc_java_util_logging_ErrorManager$sub_nonrefs	_jc_java_util_logging_ErrorManager$sub_nonrefs;
typedef struct _jc_java_util_logging_ErrorManager$refs	_jc_java_util_logging_ErrorManager$refs;
typedef struct _jc_java_util_logging_ErrorManager$nonrefs	_jc_java_util_logging_ErrorManager$nonrefs;
typedef struct _jc_java_util_logging_ErrorManager$object	_jc_java_util_logging_ErrorManager$object;

typedef struct _jc_java_util_logging_ErrorManager$fields_struct	_jc_java_util_logging_ErrorManager$fields_struct;
typedef const struct _jc_java_util_logging_ErrorManager$vmethods	_jc_java_util_logging_ErrorManager$vmethods;
typedef const struct _jc_java_util_logging_ErrorManager$vtable	_jc_java_util_logging_ErrorManager$vtable;
typedef const struct _jc_java_util_logging_ErrorManager$vtype	_jc_java_util_logging_ErrorManager$vtype;

// Class fields structure
struct _jc_java_util_logging_ErrorManager$fields_struct {
	jint	CLOSE__5fFAILURE;
	jint	FLUSH__5fFAILURE;
	jint	FORMAT__5fFAILURE;
	jint	GENERIC__5fFAILURE;
	jint	OPEN__5fFAILURE;
	jint	WRITE__5fFAILURE;
};
extern _jc_java_util_logging_ErrorManager$fields_struct _jc_java_util_logging_ErrorManager$class_fields;

// Constructors
extern void _jc_java_util_logging_ErrorManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_logging_ErrorManager$object *);

// Virtual methods
extern void _jc_java_util_logging_ErrorManager$method$error$98d48211ccc06542(_jc_env *, struct _jc_java_util_logging_ErrorManager$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *, jint);
extern void _jc_java_util_logging_ErrorManager$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_logging_ErrorManager$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_logging_ErrorManager$method_info$error$98d48211ccc06542;
extern _jc_method _jc_java_util_logging_ErrorManager$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_logging_ErrorManager$vmethods {
	void	(*error$98d48211ccc06542)(_jc_env *, struct _jc_java_util_logging_ErrorManager$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *, jint);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_logging_ErrorManager$object *);
};

// Vtable
struct _jc_java_util_logging_ErrorManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_logging_ErrorManager$vmethods	java_util_logging_ErrorManager;
};

// Vtype
struct _jc_java_util_logging_ErrorManager$vtype {
	_jc_type			type;
	_jc_java_util_logging_ErrorManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_ErrorManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_logging_ErrorManager$refs {
    _jc_java_util_logging_ErrorManager$sub_refs	java_util_logging_ErrorManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_ErrorManager$sub_nonrefs {
	jboolean	volatile everUsed;
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_ErrorManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_logging_ErrorManager$sub_nonrefs	java_util_logging_ErrorManager;
};

// Object instance structure
struct _jc_java_util_logging_ErrorManager$object {
	_jc_java_util_logging_ErrorManager$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_ErrorManager$vtype	*vtype;
	_jc_java_util_logging_ErrorManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_ErrorManager$vtype _jc_java_util_logging_ErrorManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_ErrorManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_ErrorManager$class_object;

#endif	/* _JC_java_util_logging_ErrorManager_H_ */

==> jc-1.4.6.tar.gz: java/util/logging/ErrorManager.h <==
// public class java.util.logging.ErrorManager

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bb2b34e6afd34e3a java_util_logging_ErrorManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_logging_ErrorManager_H_
#define _JC_java_util_logging_ErrorManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_util_logging_ErrorManager$sub_refs	_jc_java_util_logging_ErrorManager$sub_refs;
typedef struct _jc_java_util_logging_ErrorManager$sub_nonrefs	_jc_java_util_logging_ErrorManager$sub_nonrefs;
typedef struct _jc_java_util_logging_ErrorManager$refs	_jc_java_util_logging_ErrorManager$refs;
typedef struct _jc_java_util_logging_ErrorManager$nonrefs	_jc_java_util_logging_ErrorManager$nonrefs;
typedef struct _jc_java_util_logging_ErrorManager$object	_jc_java_util_logging_ErrorManager$object;

typedef struct _jc_java_util_logging_ErrorManager$fields_struct	_jc_java_util_logging_ErrorManager$fields_struct;
typedef const struct _jc_java_util_logging_ErrorManager$vmethods	_jc_java_util_logging_ErrorManager$vmethods;
typedef const struct _jc_java_util_logging_ErrorManager$vtable	_jc_java_util_logging_ErrorManager$vtable;
typedef const struct _jc_java_util_logging_ErrorManager$vtype	_jc_java_util_logging_ErrorManager$vtype;

// Class fields structure
struct _jc_java_util_logging_ErrorManager$fields_struct {
	jint	CLOSE__5fFAILURE;
	jint	FLUSH__5fFAILURE;
	jint	FORMAT__5fFAILURE;
	jint	GENERIC__5fFAILURE;
	jint	OPEN__5fFAILURE;
	jint	WRITE__5fFAILURE;
};
extern _jc_java_util_logging_ErrorManager$fields_struct _jc_java_util_logging_ErrorManager$class_fields;

// Constructors
extern void _jc_java_util_logging_ErrorManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_logging_ErrorManager$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_logging_ErrorManager$method$error$98d48211ccc06542(_jc_env *, struct _jc_java_util_logging_ErrorManager$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_util_logging_ErrorManager$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_logging_ErrorManager$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_logging_ErrorManager$method_info$error$98d48211ccc06542;
extern _jc_method _jc_java_util_logging_ErrorManager$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_logging_ErrorManager$vmethods {
	void	(*error$98d48211ccc06542)(_jc_env *, struct _jc_java_util_logging_ErrorManager$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *, jint) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_logging_ErrorManager$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_logging_ErrorManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_logging_ErrorManager$vmethods	java_util_logging_ErrorManager;
};

// Vtype
struct _jc_java_util_logging_ErrorManager$vtype {
	_jc_type			type;
	_jc_java_util_logging_ErrorManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_ErrorManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_logging_ErrorManager$refs {
    _jc_java_util_logging_ErrorManager$sub_refs	java_util_logging_ErrorManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_ErrorManager$sub_nonrefs {
	jboolean	volatile everUsed;
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_ErrorManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_logging_ErrorManager$sub_nonrefs	java_util_logging_ErrorManager;
};

// Object instance structure
struct _jc_java_util_logging_ErrorManager$object {
	_jc_java_util_logging_ErrorManager$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_ErrorManager$vtype	*vtype;
	_jc_java_util_logging_ErrorManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_ErrorManager$vtype _jc_java_util_logging_ErrorManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_ErrorManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_ErrorManager$class_object;

#endif	/* _JC_java_util_logging_ErrorManager_H_ */
